@@ -36,14 +36,19 @@ async fn main_async() {
     assert_eq!(doubled, expect);
 }
 
-#[cfg(feature = "runtime_async-std")]
+#[cfg(feature = "runtime-async-std")]
 #[async_std::main]
 async fn main() {
     main_async().await
 }
 
-#[cfg(feature = "runtime_tokio")]
+#[cfg(feature = "runtime-tokio")]
 #[tokio::main]
 async fn main() {
     main_async().await
 }
+
+#[cfg(feature = "runtime-smol")]
+fn main() {
+    smol::block_on(main_async())
+}
